#ifndef ConnectionListDialog_h
#define ConnectionListDialog_h

// $Id: ConnectionListDialog.h,v 1.8 2014/09/24 18:07:53 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectionAttributesModel.h"
#include "ConnectionAttributes.h"
#include "CustomDialog.h"

#include <QPushButton>

class SimpleListView;

//! handles ssh connection attributes
class ConnectionListDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //! constructor
    ConnectionListDialog( QWidget* parent = 0 );

    //! destructor
    virtual ~ConnectionListDialog( void )
    {}

    //! set connection attributes
    void setConnectionAttributes( const ConnectionAttributes::List& );

    //! get connection attributes
    ConnectionAttributes::List connectionAttributes( void ) const;

    protected Q_SLOTS:

    //! update button enability
    void _updateButtons( void );

    //! add
    void _add( void );

    //! edit
    void _edit( void );

    //! remove
    void _remove( void );

    //! move up selected task
    void _up( void );

    //! move down selected task
    void _down( void );

    private:

    //! model
    ConnectionAttributesModel& _model( void )
    { return model_; }

    //! model
    const ConnectionAttributesModel& _model( void ) const
    { return model_; }

    //! add button
    QPushButton& _addButton( void ) const
    { return *addButton_; }

    //! edit button
    QPushButton& _editButton( void ) const
    { return *editButton_; }

    //! remove button
    QPushButton& _removeButton( void ) const
    { return *removeButton_; }

    //! unicity
    bool _checkUnicity( ConnectionAttributes& );

    //! tunnel list
    SimpleListView* list_;

    //! tunnel attributes model
    ConnectionAttributesModel model_;

    //! add
    QPushButton* addButton_;

    //! edit
    QPushButton* editButton_;

    //! remove
    QPushButton* removeButton_;

    //! move up
    QPushButton* moveUpButton_;

    //! move down
    QPushButton* moveDownButton_;

};

#endif
