#ifndef SystemTrayIcon_h
#define SystemTrayIcon_h

// $Id: SystemTrayIcon.h,v 1.16 2015/01/10 17:38:33 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"

#include <QSystemTrayIcon>

class MainMenu;
class Menu;
class ToolTipWidget;
class SystemNotifications;

//* application system tray icon
class SystemTrayIcon: public QSystemTrayIcon, public Counter
{

    Q_OBJECT;

    public:

    //* constructor
    SystemTrayIcon( QObject* parent = 0 );

    //* destructor
    virtual ~SystemTrayIcon( void );

    //* main window
    MainMenu& mainMenu( void ) const
    { return *mainMenu_; }

    //* menu
    Menu& menu( void ) const
    { return *menu_; }

    //* returns true if system notifications are supported
    static bool supportsSystemNotifications( void );

    Q_SIGNALS:

    //* message available
    void messageAvailable( QString );

    protected:

    //* generic event handler
    virtual bool event( QEvent* );

    protected Q_SLOTS:

    //* activated
    void _activate( QSystemTrayIcon::ActivationReason );

    //* update tooltip
    void _updateToolTip( void );

    //* notify
    void _notify( QString );

    private:

    //* system notification
    SystemNotifications* systemNotifications_;

    //* tooltip
    ToolTipWidget* toolTipWidget_;

    //* main widget
    MainMenu* mainMenu_;

    //* menu
    Menu* menu_;

};

#endif
