// $Id: TunnelAttributes.cpp,v 1.13 2014/04/29 17:08:08 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TunnelAttributes.h"

#include "Debug.h"
#include "XmlDef.h"

//_________________________________________________________
TunnelAttributes::TunnelAttributes( void ):
Counter( "TunnelAttribute" ),
localPort_( 0 ),
remotePort_( 0 )
{ Debug::Throw( "TunnelAttributes::TunnelAttributes.\n" ); }

//_________________________________________________________
TunnelAttributes::TunnelAttributes( const QDomElement& element ):
    Counter( "TunnelAttributes" ),
    localPort_( 0 ),
    remotePort_( 0 )
{
    Debug::Throw( "TunnelAttributes::TunnelAttributes.\n" );

    // parse attributes
    QDomNamedNodeMap attributes( element.attributes() );
    for( int i=0; i<attributes.count(); i++ )
    {

        QDomAttr attribute( attributes.item( i ).toAttr() );
        if( attribute.isNull() ) continue;
        QString name( attribute.name() );
        QString value( attribute.value() );

        if( name == Xml::Host ) setHost( value );
        else if( name == Xml::LocalPort ) setLocalPort( value.toInt() );
        else if( name == Xml::RemotePort ) setRemotePort( value.toInt() );
        else Debug::Throw(0) << "TunnelAttributes::TunnelAttributes - unrecognized name " << name << endl;

    }

}

//_________________________________________________________
QDomElement TunnelAttributes::domElement( QDomDocument& document ) const
{
    Debug::Throw( "TunnelAttributes::domElement.\n" );
    QDomElement out( document.createElement( Xml::Tunnel ) );

    // attributes
    out.setAttribute( Xml::Host, host() );
    out.setAttribute( Xml::LocalPort, QString::number( localPort() ) );
    out.setAttribute( Xml::RemotePort, QString::number( remotePort() ) );
    return out;

}

//_________________________________________________________
QStringList TunnelAttributes::errors( void ) const
{
    QStringList out;
    if( host().isEmpty() ) out << QObject::tr( "  Invalid hostname;" );
    if( localPort() == 0 ) out << QObject::tr( "  Invalid local port;" );
    if( remotePort() == 0 ) out << QObject::tr( "  Invalid remote port;" );
    return out;
}

//_________________________________________________________
bool TunnelAttributes::isValid( void ) const
{ return !( host().isEmpty() || localPort() == 0 || remotePort() == 0 ); }
