// $Id: TunnelDialog.cpp,v 1.11 2014/09/26 08:06:18 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QLabel>
#include <QLayout>

#include "TunnelDialog.h"
#include "TunnelDialog.moc"
#include "AnimatedLineEditor.h"
#include "AnimatedTreeView.h"
#include "GridLayout.h"
#include "IconEngine.h"
#include "IconNames.h"

//___________________________________________________________
TunnelDialog::TunnelDialog( QWidget* parent ):
CustomDialog(parent, OkButton|CancelButton )
{

    Debug::Throw( "TunnelDialog::TunnelDialog.\n" );
    setOptionName( "TUNNEL_DIALOG" );

    // grid layout
    GridLayout* gridLayout( new GridLayout() );
    gridLayout->setMargin(0);
    gridLayout->setSpacing(5);
    gridLayout->setMaxCount(2);
    gridLayout->setColumnAlignment(0, Qt::AlignRight|Qt::AlignVCenter );
    mainLayout().addLayout( gridLayout );

    QLabel* label;
    gridLayout->addWidget( label = new QLabel( tr( "Local Port:" ), this ) );
    gridLayout->addWidget( localPortSpinBox_ = new QSpinBox( this ) );
    localPortSpinBox_->setMinimum( 0 );
    localPortSpinBox_->setMaximum( 100000 );
    label->setBuddy( localPortSpinBox_ );

    gridLayout->addWidget( label = new QLabel( tr( "Host:" ), this ) );
    gridLayout->addWidget( hostEditor_ = new AnimatedLineEditor( this ) );
    label->setBuddy( hostEditor_ );

    gridLayout->addWidget( label = new QLabel( tr( "Remote Port:" ), this ) );
    gridLayout->addWidget( remotePortSpinBox_ = new QSpinBox( this ) );
    remotePortSpinBox_->setMinimum( 0 );
    remotePortSpinBox_->setMaximum( 100000 );
    label->setBuddy( remotePortSpinBox_ );

    okButton().setText( tr( "Save Tunnel" ) );
    okButton().setIcon( IconEngine::get( IconNames::Save ) );

}


//________________________________________
void TunnelDialog::setTunnelAttributes( const TunnelAttributes& attributes )
{
    Debug::Throw( "TunnelDialog::setTunnelAttributes.\n" );

    // update editors
    localPortSpinBox_->setValue( attributes.localPort() );
    remotePortSpinBox_->setValue( attributes.remotePort() );
    hostEditor_->setText( attributes.host() );

}

//________________________________________
TunnelAttributes TunnelDialog::tunnelAttributes( void ) const
{
    Debug::Throw( "TunnelDialog::tunnelAttributes.\n" );
    TunnelAttributes out;
    out.setLocalPort( localPortSpinBox_->value() );
    out.setRemotePort( remotePortSpinBox_->value() );
    out.setHost( hostEditor_->text() );
    return out;
}
